@@ -20,6 +20,9 @@ FAILEDOPERATION = 'FailedOperation'
 # FailedOperation.CertificateVerificationFailed
 FAILEDOPERATION_CERTIFICATEVERIFICATIONFAILED = 'FailedOperation.CertificateVerificationFailed'
 
+# 策略优先级重复
+FAILEDOPERATION_DUPLICATEAUTHORIZATIONIDORPRIORITY = 'FailedOperation.DuplicateAuthorizationIdOrPriority'
+
 # FailedOperation.InstanceNotReady
 FAILEDOPERATION_INSTANCENOTREADY = 'FailedOperation.InstanceNotReady'
 
@@ -47,6 +50,9 @@ OPERATIONDENIED = 'OperationDenied'
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
+# 授权策略未找到
+RESOURCENOTFOUND_AUTHORIZATIONPOLICY = 'ResourceNotFound.AuthorizationPolicy'
+
 # ResourceNotFound.Instance
 RESOURCENOTFOUND_INSTANCE = 'ResourceNotFound.Instance'
 
@@ -56,6 +62,9 @@ RESOURCENOTFOUND_ROLE = 'ResourceNotFound.Role'
 # ResourceNotFound.Topic
 RESOURCENOTFOUND_TOPIC = 'ResourceNotFound.Topic'
 
+# 用户名未找到
+RESOURCENOTFOUND_USERNAME = 'ResourceNotFound.Username'
+
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
